@@ -14,10 +14,6 @@ test_that("error occurs when Groups are not specified ",{
         expect_error(PlotRE(PhyloExpressionSetExample),"Your Groups list does not store any items.")
 })
 
-test_that("error occurs when legendName is not specified",{
-        
-        expect_error(PlotRE(PhyloExpressionSetExample,list(1:3,4:12)),"lease specify the type of ExpressionSet you are working with: legendName = 'PS' or 'DS'.")
-})
 
 test_that("error occurs when PS or DS are specified in Groups which are not present in the ExpressionSet ",{
         
